@@ -1,20 +1,17 @@
-import sys
-
 from flask import Flask
 from flask_restx import Api
 from injector import inject
 from werkzeug.exceptions import HTTPException
 from flask_cors import CORS
 
-from pdip.api.base.resource_base import ResourceBase
-
-from ..handlers.error_handlers import ErrorHandlers
-from ..handlers.request_handler import RequestHandler
+from ..handlers import ErrorHandlers
+from ..handlers import RequestHandler
+from ...api.base import ResourceBase
 from ...configuration.models.api import ApiConfig
 from ...configuration.models.application import ApplicationConfig
 
-from ...dependency.scopes import ISingleton
-from ...exceptions.operational_exception import OperationalException
+from ...dependency import ISingleton
+from ...exceptions import OperationalException
 
 
 class FlaskAppWrapper(ISingleton):
@@ -48,13 +45,6 @@ class FlaskAppWrapper(ISingleton):
         self.app.register_error_handler(HTTPException, self.error_handlers.handle_http_exception)
         self.app.after_request(self.request_handler.after_request)
 
-    # def find_resources(self):
-    #     for resource in ResourceBase.__subclasses__():
-    #         if sys.modules[resource.__module__].__file__.startswith(self.application_config.root_directory):
-    #             con = Controller(
-    #                 cls=resource, api=self.api, application_config=self.application_config, namespace=None, route=None)
-    #             con.create_route()
-
     def run(self):
         self.app.run(debug=self.api_config.is_debug, host='0.0.0.0', port=self.api_config.port)
 
