@@ -1,7 +1,8 @@
 from cryptography.fernet import Fernet
 from injector import inject
+
+from ..configuration.models.application import ApplicationConfig
 from ..dependency.scopes import IScoped
-from ..configuration.models import ApplicationConfig
 
 
 class CryptoService(IScoped):
